==> hypersnapsdk_flutter-1.0.11.tar.gz: CHANGELOG.md <==
## 0.0.1

- 1st release of HyperSnap SDK Flutter plugin 

## 0.0.2

- Minor updates to plugin docs

## 1.0.0

- Add more APIs and functionalities
- Upgrade native SDK versions

## 1.0.1

- Bug fix in `FLHVFaceCapture#setUIStrings`

## 1.0.2

- Upgrade native SDK versions
- Add more APIs and functionalities
- Bug fix in response structures from native SDKs

## 1.0.3

- Bug fix in `FLHVDocsCapture#setUIStrings` : iOS error page retake button text

## 1.0.4

- Add extra layers of security to HyperSnapSDK
- Add more APIs and functionalities

## 1.0.5 [22 Sept 2021]

- Upgrade native SDK versions (android to 3.6.7 and iOS to 2.6.11)
- Fix view controller related bug

## 1.0.6 [07 Oct 2021]

- Upgrade native SDK versions (android to 3.6.8 and iOS to 2.7.0)
- Update usage of livenessAPIParameters and livenessAPIHeaders
- Update startUserSession logic in wrapper files

## 1.0.7 [11 Nov 2021]

- Upgrade native android hypersnapsdk version to 3.6.13
- Bug fixes
- Add more APIs and functionalities (video recording support for android platform)

## 1.0.8 [16 Dec 2021]

- Upgrade native android hypersnapsdk version to 3.6.18
- Add Region Africa support
- Bug fixes

## 1.0.9 [18 March 2022]

- Enable setting default padding for iOS platform using the function 
  `docsCaptureSetDefaultPadding` function

## 1.0.10 [28 March 2022]

- Fix `docsCaptureSetDefaultPadding` function bug
- Fix RegionAfrica bug in iOS wrapper files
- Upgrade native android hypersnapsdk version to 3.6.27, native iOS hypersnapsdk version to 2.7.6

## 1.0.11 [30 March 2022]

- Minor bug fixes

==> hypersnapsdk_flutter-1.1.4.tar.gz: CHANGELOG.md <==
## Changelog

## 1.1.4 [12 Sep 2022]

- Fix document type and aspect ratio issue

## 1.1.3 [18 Aug 2022]

- Fix text customisation issues
- Add support for loading screen text customisation
- Upgrade native android hypersnapsdk to 4.1.3, native iOS hypersnapsdk to 4.1.6

## 1.1.2 [05 Aug 2022]

- Support custom endpoints for face match
- Support different face match modes for face match
- Upgrade native android hypersnapsdk to 4.1.2, native iOS hypersnapsdk to 4.1.5

## 1.1.1 [22 Jul 2022]

- Add QR scanner feature
- Upgrade native android hypersnapsdk to 4.1.1, native iOS hypersnapsdk to 4.1.3

## 1.1.0 [21 Jun 2022]

- New UI/UX
- Upgrade native android hypersnapsdk to 4.1.0-alpha01, native iOS hypersnapsdk to 4.1.1
- Support selfie auto capture feature and video recording feature

## 1.0.12 [2 May 2022]

- Client should get both error and response.
- Upgrade native android hypersnapsdk to 3.6.29

## 1.0.11 [30 Mar 2022]

- Minor bug fixes

## 1.0.10 [28 Mar 2022]

- Fix `docsCaptureSetDefaultPadding` function bug
- Fix RegionAfrica bug in iOS wrapper files
- Upgrade native android hypersnapsdk version to 3.6.27, native iOS hypersnapsdk version to 2.7.6

## 1.0.9 [18 Mar 2022]

- Enable setting default padding for iOS platform using the function
  `docsCaptureSetDefaultPadding` function

## 1.0.8 [16 Dec 2021]

- Upgrade native android hypersnapsdk version to 3.6.18
- Add Region Africa support
- Bug fixes

## 1.0.7 [11 Nov 2021]

- Upgrade native android hypersnapsdk version to 3.6.13
- Bug fixes
- Add more APIs and functionalities (video recording support for android platform)

## 1.0.6 [07 Oct 2021]

- Upgrade native SDK versions (android to 3.6.8 and iOS to 2.7.0)
- Update usage of livenessAPIParameters and livenessAPIHeaders
- Update startUserSession logic in wrapper files

## 1.0.5 [22 Sept 2021]

- Upgrade native SDK versions (android to 3.6.7 and iOS to 2.6.11)
- Fix view controller related bug

## 1.0.4

- Add extra layers of security to HyperSnapSDK
- Add more APIs and functionalities

## 1.0.3

- Bug fix in `FLHVDocsCapture#setUIStrings` : iOS error page retake button text

## 1.0.2

- Upgrade native SDK versions
- Add more APIs and functionalities
- Bug fix in response structures from native SDKs

## 1.0.1

- Bug fix in `FLHVFaceCapture#setUIStrings`

## 1.0.0

- Add more APIs and functionalities
- Upgrade native SDK versions

## 0.0.2

- Minor updates to plugin docs

## 0.0.1

- 1st release of HyperSnap SDK Flutter plugin
